@@ -34,5 +34,5 @@ class ASMCode(Code):
 
         return cast(
             bytes,
-            assembler.asm(self.code, vaddr, as_bytes=True),
+            assembler.asm(self.code, vaddr, as_bytes=True)[0],
         )
